@@ -77,6 +77,9 @@ class DerivedFromFile:
 
         `workflow_inputs_to_match` can be used to indicate that only files with
         filenames matching the workflow input keys given should be considered.
+
+        `only_search_current_analysis` will only consider direct ancestors in the WDL
+        call graph when generating the `derived_from`
         """
         self.allow_empty: bool = derived_from_file.get("allow_empty", False)
         self.derived_from_filekey: str = derived_from_file["derived_from_filekey"]
@@ -95,6 +98,9 @@ class DerivedFromFile:
         if not isinstance(workflow_inputs_to_match, list):
             raise ValueError("`workflow_inputs_to_match` must be an array")
         self.workflow_inputs_to_match: List[str] = workflow_inputs_to_match
+        self.only_search_current_analysis: bool = derived_from_file.get(
+            "only_search_current_analysis", False
+        )
 
 
 class FileParams:
