@@ -32,7 +32,9 @@ from accession.encode_models import (
     EncodeExperiment,
     EncodeFile,
 )
+from accession.file import GSFile
 from accession.metadata import FileMetadata
+from accession.task import Task
 
 
 @pytest.fixture(scope="session")
@@ -200,6 +202,21 @@ def encode_document(encode_attachment, encode_common_metadata):
     )
 
 
+@pytest.fixture
+def gsfile():
+    task = {
+        "inputs": {
+            "prefix": "pooled-pr1_vs_pooled-pr2",
+            "fastqs_R1": ["gs://abc/spam.fastq.gz"],
+        },
+        "outputs": {},
+    }
+    my_task = Task("my_task", task)
+    return GSFile(
+        "foo", "gs://abc/spam.fastq.gz", md5sum="123", size="456", task=my_task
+    )
+
+
 @attr.s(auto_attribs=True)
 class MockFile:
     filename: str
