@@ -46,6 +46,7 @@ def encode_experiment():
         "replicates": [
             {"biological_replicate_number": 1},
             {"biological_replicate_number": 3},
+            {"technical_replicate_number": 42},
         ],
     }
     return EncodeExperiment(properties)
@@ -324,6 +325,10 @@ def test_encode_experiment_get_number_of_biological_replicates(encode_experiment
     assert encode_experiment.get_number_of_biological_replicates() == 2
 
 
+def test_encode_experiment_get_number_of_technical_replicates(encode_experiment):
+    assert encode_experiment.get_number_of_technical_replicates() == 1
+
+
 def test_encode_experiment_is_replicated(encode_experiment):
     assert encode_experiment.is_replicated is True
 
